@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: adjunctions
 version: 4.3
-id: adjunctions-4.3-e46cf12f2e7e306822764e6eb775fdd9
-key: adjun_JgKV37RcHRvGDaxmTWmd9D
+id: adjunctions-4.3-c475a106420800be166b9b6982c59446
+key: adjun_0qyiUsQIKFUKOnkWyF145T
 license: BSD3
 copyright: Copyright (C) 2011-2014 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -26,23 +26,23 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/adjunctions-4.3
-hs-libraries: HSadjunctions-4.3-JgKV37RcHRvGDaxmTWmd9D
+hs-libraries: HSadjunctions-4.3-0qyiUsQIKFUKOnkWyF145T
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    comonad-5-a91321d086a2de4a04a44d60c347669e
+    comonad-5-e98e7adc8875accf64a86529d9aeae51
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    contravariant-1.4-7b1149a75def92c79deb23a86e0b36cb
+    contravariant-1.4-6e8bc7cb2457226c1a88750295477d07
     distributive-0.5.0.2-6c580c91b8bf5de803bfa850eb262f37
-    free-4.12.4-d9a4c0f5afbed93cf1b5cb75cd23ad91
+    free-4.12.4-a5ffddbbf41dcb5e4b11e5d62a21f456
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    profunctors-5.2-dcebd670a79351324a9f8d71a72c88e3
-    semigroupoids-5.0.1-d6a1ac9616a3b8232f6b4a54c12a0db0
-    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
+    profunctors-5.2-aaf86384a4db0133740cbda80ff5e59a
+    semigroupoids-5.0.1-7b21d348d4b507a23638386627368bec
+    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
-    void-0.7.1-5ad9ec6793ffb57ac26a200023a4290d
+    void-0.7.1-5298c6b3a32576797627b9b87532f9cb
 haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
 haddock-html: /usr/share/doc/haskell-adjunctions/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
